@@ -14,10 +14,10 @@
 
 
 from fastapi import FastAPI
-from servz import ModelCore
+import {predict}
 
 app = FastAPI()
 
 @app.get("/")
 async def root():
-    return ModelCore.load().predict()
\ No newline at end of file
+    return {predict}.predict()
\ No newline at end of file
